@@ -523,7 +523,6 @@ function opgc_loadPreferences() {
 		document.getElementById("opgc-Etiquette_Emplacement").value = contenu.getAttribute("Etiquette_Emplacement");
 		document.getElementById("opgc-Field_Column_DL_1").value = contenu.getAttribute("Field_Column_DL_1");
 		document.getElementById("opgc-Field_Column_DL_2").value = contenu.getAttribute("Field_Column_DL_2");
-		document.getElementById("opgc-Lien_Fichier").value = contenu.getAttribute("Lien_Fichier");
 		document.getElementById("opgc-Assoc_Acces_FTP").value = contenu.getAttribute("Assoc_Acces_FTP");
 		document.getElementById("opgc-Assoc_Dossier_FTP").value = contenu.getAttribute("Assoc_Dossier_FTP");
 		document.getElementById("opgc-Imp_Desc1_Fiche").checked = contenu.getAttribute("Imp_Desc1_Fiche")=="true";
@@ -659,7 +658,6 @@ function opgc_updatePreferences() {
 		var etiquetteEmplacement = document.getElementById("opgc-Etiquette_Emplacement").value;
 		var fieldColumnDL1 = document.getElementById("opgc-Field_Column_DL_1").value;
 		var fieldColumnDL2 = document.getElementById("opgc-Field_Column_DL_2").value;
-		var lienFichier = document.getElementById("opgc-Lien_Fichier").value;
 		var assocAccesFTP = document.getElementById("opgc-Assoc_Acces_FTP").value;
 		var assocDossierFTP = document.getElementById("opgc-Assoc_Dossier_FTP").value;
 		var impDesc1Fiche = document.getElementById("opgc-Imp_Desc1_Fiche").checked;
@@ -807,7 +805,6 @@ function opgc_updatePreferences() {
 			qUpdate.setParam("Etiquette_Emplacement", etiquetteEmplacement);
 			qUpdate.setParam("Field_Column_DL_1", fieldColumnDL1);
 			qUpdate.setParam("Field_Column_DL_2", fieldColumnDL2);
-			qUpdate.setParam("Lien_Fichier", lienFichier);
 			qUpdate.setParam("Assoc_Acces_FTP", assocAccesFTP);
 			qUpdate.setParam("Assoc_Dossier_FTP", assocDossierFTP);
 			qUpdate.setParam("Imp_Desc1_Fiche", impDesc1Fiche);
