@@ -196,7 +196,7 @@ function ofsEnregistrer(quit) {
 			qSave.setParam("Prenom", document.getElementById("ofs-prenom").value);
 			qSave.setParam("Num_SIRET", document.getElementById("ofs-numSIRET").value);
 			qSave.setParam("Code_NAF", document.getElementById("ofs-codeNAF").value);
-			qSave.setParam("Num_TVA_Intra", document.getElementById("ofs-numTVA").value);
+			qSave.setParam("Numero_TVA", document.getElementById("ofs-numTVA").value);
 			qSave.setParam("Type_Client", document.getElementById("ofs-typeClient").value);
 			qSave.setParam("Forme_Juridique", document.getElementById("ofs-formeJuridique").value);
 
@@ -345,7 +345,7 @@ function initialiser(type) {
 			document.getElementById("ofs-nom").value = result.responseXML.documentElement.getAttribute("Nom");
 			document.getElementById("ofs-prenom").value = result.responseXML.documentElement.getAttribute("Prenom");
 			document.getElementById("ofs-numSIRET").value = result.responseXML.documentElement.getAttribute("Num_SIRET");
-			document.getElementById("ofs-numTVA").value = result.responseXML.documentElement.getAttribute("Num_TVA_Intra");
+			document.getElementById("ofs-numTVA").value = result.responseXML.documentElement.getAttribute("Numero_TVA");
 			document.getElementById("ofs-codeNAF").value = result.responseXML.documentElement.getAttribute("Code_NAF");
 			document.getElementById("ofs-typeClient").value = result.responseXML.documentElement.getAttribute("Type_Client");
 			document.getElementById("ofs-formeJuridique").value = result.responseXML.documentElement.getAttribute("Forme_Juridique");
