@@ -171,7 +171,7 @@ function oma_init() {
 			document.getElementById('oma-bNouveau').collapsed = true;
 		}
 
-		document.getElementById('oma-reference').focus();
+		setTimeout("document.getElementById('oma-reference').focus()",0);
 
 		oma_loadChiffresCles();
 
