@@ -42,6 +42,7 @@ var ofc_defautModeFacturation;
 var ofc_defautBLChiffre;
 var ofc_defautModeReglement;
 var ofc_defautModaliteReg;
+var ofc_tarifDefaut;
 
 
 
@@ -67,10 +68,15 @@ function ofc_init() {
 		ofc_defautBLChiffre = gConfig.isBLChiffre();
 		ofc_defautModeReglement = gConfig.getDefModeReglementC();
 		ofc_defautModaliteReg = gConfig.getDefModaliteC();
+		ofc_tarifDefaut = gConfig.getTarifDefaut();
 
 		document.getElementById('ofc-grossiste').collapsed = !gConfig.isSpecLCAGGC();
 		document.getElementById('ofc-appTarifClient').collapsed = !gConfig.isSpecLCAOTC();
 
+		if (gConfig.isGDVSituation()) {
+			document.getElementById('ofc-modeFactFS').setAttribute("hidden", false);
+		}
+
 		if (gConfig.isSpecTKPA()) {
 			ofc_defautPoleActivite = gProfil.getPoleActivite();
 		}
@@ -523,7 +529,10 @@ function ofc_pressOnModeFacturation() {
 		if (modeFacturation=="B") {
 			document.getElementById('ofc-factAvantLiv').checked = false;
 		}
-		document.getElementById('ofc-factAvantLiv').disabled = (modeFacturation=="B");
+		if (modeFacturation=="S") {
+			document.getElementById('ofc-factAvantLiv').checked = true;
+		}
+		document.getElementById('ofc-factAvantLiv').disabled = (modeFacturation=="B" || modeFacturation=="S");
 
 	} catch (e) {
 		recup_erreur(e);
@@ -643,7 +652,7 @@ function ofc_nouveauClient() {
 		document.getElementById('ofc-comLibre').value = "";
 		document.getElementById('ofc-codeCouleur').value = 2;
 		document.getElementById('ofc-formeJuridique').value = "";
-		document.getElementById('ofc-numTVAIntra').value = "";
+		document.getElementById('ofc-numeroTVA').value = "";
 		document.getElementById('ofc-numSIRET').value = "";
 		document.getElementById('ofc-codeNAF').value = "";
 		ofc_chargerPolesActivite(ofc_defautPoleActivite);
@@ -668,7 +677,7 @@ function ofc_nouveauClient() {
 		document.getElementById('ofc-regimeTVA').value = "G";
 		document.getElementById('ofc-tauxRemise').value = "0.00";
 		document.getElementById('ofc-tauxEscompte').value = "0.00";
-		document.getElementById('ofc-tarifId').selectedIndex = 0;
+		document.getElementById('ofc-tarifId').value = ofc_tarifDefaut;
 		document.getElementById('ofc-appTarifClient').checked = false;
 		document.getElementById('ofc-nbEx').value = 1;
 		document.getElementById('ofc-nbBon').value = 1;
@@ -676,11 +685,11 @@ function ofc_nouveauClient() {
 		document.getElementById('ofc-comFact').value = "";
 		document.getElementById('ofc-encoursAuto').value = "0.00";
 		document.getElementById('ofc-encoursFact').value = "0.00";
-		document.getElementById('ofc-factAvantLiv').checked = ofc_defautFactAvantLiv;
+		document.getElementById('ofc-factAvantLiv').checked = ofc_defautFactAvantLiv || ofc_defautModeFacturation=="S";
 		document.getElementById('ofc-periodeFacturation').value = ofc_defautPeriodeFacturation;
 		document.getElementById('ofc-modeEnvoiFacture').value = ofc_defautModeEnvoiFacture;
 		document.getElementById('ofc-envoiDetailFC').checked = false;
-		document.getElementById('ofc-factAvantLiv').disabled = (ofc_defautModeFacturation=="B");
+		document.getElementById('ofc-factAvantLiv').disabled = (ofc_defautModeFacturation=="B" || ofc_defautModeFacturation=="S");
 		document.getElementById('ofc-bonChiffre').checked = ofc_defautBLChiffre;
 		document.getElementById('ofc-mwmControlePicking').checked = false;
 		document.getElementById('ofc-francoPort').checked = false;
@@ -747,7 +756,7 @@ function ofc_chargerClient() {
 		document.getElementById('ofc-comLibre').value = contenu.getAttribute('Com_Libre');
 		document.getElementById('ofc-codeCouleur').value = contenu.getAttribute('Code_Couleur');
 		document.getElementById('ofc-formeJuridique').value = contenu.getAttribute('Forme_Juridique');
-		document.getElementById('ofc-numTVAIntra').value = contenu.getAttribute('Num_TVA_Intra');
+		document.getElementById('ofc-numeroTVA').value = contenu.getAttribute('Numero_TVA');
 		document.getElementById('ofc-numSIRET').value = contenu.getAttribute('Num_SIRET');
 		document.getElementById('ofc-codeNAF').value = contenu.getAttribute('Code_NAF');
 		document.getElementById('ofc-codeFournisseur').value = contenu.getAttribute('Code_Fournisseur');
@@ -779,7 +788,8 @@ function ofc_chargerClient() {
 		document.getElementById('ofc-appTarifClient').checked = contenu.getAttribute('App_Tarif_Client')=="true";
 		document.getElementById('ofc-nbEx').value = contenu.getAttribute('Nb_Ex');
 		document.getElementById('ofc-nbBon').value = contenu.getAttribute('Nb_Bon');
-		document.getElementById('ofc-modeFacturation').value = contenu.getAttribute('Mode_Facturation');
+		var modeFacturation = contenu.getAttribute('Mode_Facturation');
+		document.getElementById('ofc-modeFacturation').value = modeFacturation;
 		document.getElementById('ofc-comFact').value = contenu.getAttribute('Com_Fact');
 		document.getElementById('ofc-encoursAuto').value = contenu.getAttribute('Encours_Auto');
 		document.getElementById('ofc-encoursFact').value = contenu.getAttribute('Encours_Fact');
@@ -787,7 +797,7 @@ function ofc_chargerClient() {
 		document.getElementById('ofc-periodeFacturation').value = contenu.getAttribute('Periode_Facturation');
 		document.getElementById('ofc-modeEnvoiFacture').value = contenu.getAttribute('Mode_Envoi_Facture');
 		document.getElementById('ofc-envoiDetailFC').checked = contenu.getAttribute('Envoi_Detail_FC')=="true";
-		document.getElementById('ofc-factAvantLiv').disabled = (contenu.getAttribute('Mode_Facturation')=="B");
+		document.getElementById('ofc-factAvantLiv').disabled = (modeFacturation=="B" || modeFacturation=="S");
 		document.getElementById('ofc-bonChiffre').checked = (contenu.getAttribute('Bon_Chiffre')=="true");
 		document.getElementById('ofc-mwmControlePicking').checked = (contenu.getAttribute('MWM_Controle_Picking')=="true");
 		document.getElementById('ofc-codeRegroupement').value = contenu.getAttribute('Code_Regroupement');
@@ -859,7 +869,7 @@ function ofc_enregistrerClient() {
 		var comLibre = document.getElementById('ofc-comLibre').value;
 		var codeCouleur = document.getElementById('ofc-codeCouleur').value;
 		var formeJuridique = document.getElementById('ofc-formeJuridique').value;
-		var numTVAIntra = document.getElementById('ofc-numTVAIntra').value;
+		var numeroTVA = document.getElementById('ofc-numeroTVA').value;
 		var numSIRET = document.getElementById('ofc-numSIRET').value;
 		var codeNAF = document.getElementById('ofc-codeNAF').value;
 		var famille = document.getElementById('ofc-famille').value;
@@ -933,7 +943,8 @@ function ofc_enregistrerClient() {
 		else if (isEmpty(tauxEscompte) || !isTaux(tauxEscompte) || parseFloat(tauxEscompte)>=100) { showWarning("Taux d'escompte incorrect (Onglet \u00E9l\u00E9ments de gestion)"); }
 		else if (isEmpty(encoursAuto) || !isPositiveOrNull(encoursAuto)) { showWarning("Encours total autoris\u00E9 incorrect (Onglet \u00E9l\u00E9ments de gestion)"); }
 		else if (isEmpty(encoursFact) || !isPositiveOrNull(encoursFact)) { showWarning("Encours de facturation autoris\u00E9 incorrect (Onglet \u00E9l\u00E9ments de gestion)"); }
-		else if (modeFacturation=="B" && factAvantLiv) { showWarning("Le type de facturation par BL et le mode de facturation par commande sont incompatibles (Onglet \u00E9l\u00E9ments de gestion)"); }
+		else if (modeFacturation=="B" && factAvantLiv) { showWarning("Le mode de facturation par BL et la facturation avant livraison sont incompatibles (Onglet \u00E9l\u00E9ments de gestion)"); }
+		else if (modeFacturation=="S" && !factAvantLiv) { showWarning("L'option de facturation avant livraison doit \u00EAtre coch\u00E9e avec le mode de facturation de situation (Onglet \u00E9l\u00E9ments de gestion)"); }
 		else if (francoPort && !isPositiveOrNull(montantFranco)) { showWarning("Le montant du franco de port est incorrect (Onglet \u00E9l\u00E9ments de gestion)"); }
 		else if (ofc_typePort=='P'?!isTaux(fraisPort):!isPositiveOrNull(fraisPort)) { showWarning("Le montant des frais de port est incorrect (Onglet \u00E9l\u00E9ments de gestion)"); }
 		else {
@@ -948,7 +959,7 @@ function ofc_enregistrerClient() {
 				showWarning("Attention : vous n'avez pas coch\u00E9 la case assujetti \u00E0 la tva bien que votre client soit une entreprise");
 			}
 
-			if (assujettiTVA && codePays!="FR" && isEmpty(numTVAIntra)) {
+			if (assujettiTVA && codePays!="FR" && isEmpty(numeroTVA)) {
 				var qZoneUE = new QueryHttp("Facturation/Commun/getZoneUEPays.tmpl");
 				qZoneUE.setParam("Code_Pays", codePays);
 				var result = qZoneUE.execute();
@@ -991,7 +1002,7 @@ function ofc_enregistrerClient() {
 			qSave.setParam("Com_Libre", comLibre);
 			qSave.setParam("Code_Couleur", codeCouleur);
 			qSave.setParam("Forme_Juridique", formeJuridique);
-			qSave.setParam("Num_TVA_Intra", numTVAIntra);
+			qSave.setParam("Numero_TVA", numeroTVA);
 			qSave.setParam("Num_SIRET", numSIRET);
 			qSave.setParam("Code_NAF", codeNAF);
 			qSave.setParam("Famille_Id", famille);
