@@ -464,7 +464,7 @@ function off_nouveauFournisseur() {
 		document.getElementById('off-comLibre').value = "";
 		document.getElementById('off-codeCouleur').value = 2;
 		document.getElementById('off-formeJuridique').value = "";
-		document.getElementById('off-numTVAIntra').value = "";
+		document.getElementById('off-numeroTVA').value = "";
 		document.getElementById('off-numSIRET').value = "";
 		document.getElementById('off-codeNAF').value = "";
 		off_chargerPolesActivite("");
@@ -551,7 +551,7 @@ function off_chargerFournisseur() {
 		document.getElementById('off-comLibre').value = contenu.getAttribute('Com_Libre');
 		document.getElementById('off-codeCouleur').value = contenu.getAttribute('Code_Couleur');
 		document.getElementById('off-formeJuridique').value = contenu.getAttribute('Forme_Juridique');
-		document.getElementById('off-numTVAIntra').value = contenu.getAttribute('Num_TVA_Intra');
+		document.getElementById('off-numeroTVA').value = contenu.getAttribute('Numero_TVA');
 		document.getElementById('off-numSIRET').value = contenu.getAttribute('Num_SIRET');
 		document.getElementById('off-codeNAF').value = contenu.getAttribute('Code_NAF');
 		document.getElementById('off-codeClient').value = contenu.getAttribute('Code_Client');
@@ -635,7 +635,7 @@ function off_enregistrerFournisseur() {
 		var comLibre = document.getElementById('off-comLibre').value;
 		var codeCouleur = document.getElementById('off-codeCouleur').value;
 		var formeJuridique = document.getElementById('off-formeJuridique').value;
-		var numTVAIntra = document.getElementById('off-numTVAIntra').value;
+		var numeroTVA = document.getElementById('off-numeroTVA').value;
 		var numSIRET = document.getElementById('off-numSIRET').value;
 		var codeNAF = document.getElementById('off-codeNAF').value;
 		var famille = document.getElementById('off-famille').value;
@@ -726,7 +726,7 @@ function off_enregistrerFournisseur() {
 			qSave.setParam("Com_Libre", comLibre);
 			qSave.setParam("Code_Couleur", codeCouleur);
 			qSave.setParam("Forme_Juridique", formeJuridique);
-			qSave.setParam("Num_TVA_Intra", numTVAIntra);
+			qSave.setParam("Numero_TVA", numeroTVA);
 			qSave.setParam("Num_SIRET", numSIRET);
 			qSave.setParam("Code_NAF", codeNAF);
 			qSave.setParam("Famille_Id", famille);
