@@ -433,8 +433,13 @@ function oei_reporterLigneInventaire() {
 			document.getElementById('oei-emplacement').value = oei_aLignes.getSelectedCellText('oei-colCodeEmplacement');
 			document.getElementById('oei-reference').value = oei_aLignes.getSelectedCellText('oei-colReference');
 			document.getElementById('oei-designation').value = oei_aLignes.getSelectedCellText('oei-colDesignation');
-			document.getElementById('oei-qteTheorique').value = oei_aLignes.getSelectedCellText('oei-colQteTheorique');
-			document.getElementById('oei-qteInventaire').value = oei_aLignes.getSelectedCellText('oei-colQteTheorique');
+			var qteTheorique = oei_aLignes.getSelectedCellText('oei-colQteTheorique');
+			document.getElementById('oei-qteTheorique').value = qteTheorique;
+			if (parseFloat(qteTheorique)<0) {
+				qteTheorique = 0;
+			}
+			document.getElementById('oei-qteInventaire').value = qteTheorique;
+
 			oei_currentLigneId = oei_aLignes.getSelectedCellText('oei-colLigneId');
 			oei_currentIndex = oei_aLignes.getCurrentIndex();
 
