@@ -179,6 +179,9 @@ function Config() {
 	this.gacAffAvoirCC = contenu.getAttribute("GAC_Aff_Avoir_CC")=="true";
 	this.gacDefFiltreDepot = contenu.getAttribute("GAC_Def_Filtre_Depot");
 	this.gdfDefFiltreDepot = contenu.getAttribute("GDF_Def_Filtre_Depot");
+	this.gacAlerteMRFC = contenu.getAttribute("GAC_Alerte_MR_FC")=="true";
+	this.gdvPrimeCEE = contenu.getAttribute("GDV_Prime_CEE")=="true";
+	this.gdvSituation = contenu.getAttribute("GDV_Situation")=="true";
 
 	this.compteClients = contenu.getAttribute("Compte_Clients");
 	this.journalAchat = contenu.getAttribute("Journal_Achat");
@@ -229,7 +232,6 @@ function Config() {
 	this.specLCARMC = contenu.getAttribute("Spec_LCA_RMC")=="true";
 	this.specLCAREC = contenu.getAttribute("Spec_LCA_REC")=="true";
 	this.specLCAOTC = contenu.getAttribute("Spec_LCA_OTC")=="true";
-	this.specREAFL = contenu.getAttribute("Spec_RE_AFL")=="true";
 }
 
 
@@ -393,6 +395,9 @@ Config.prototype.isGDCRespCreateur = function() { return this.gdcRespCreateur; }
 Config.prototype.isGACAffAvoirCC = function() { return this.gacAffAvoirCC; }
 Config.prototype.getGACDefFiltreDepot = function() { return this.gacDefFiltreDepot; }
 Config.prototype.getGDFDefFiltreDepot = function() { return this.gdfDefFiltreDepot; }
+Config.prototype.isGACAlerteMRFC = function() { return this.gacAlerteMRFC; }
+Config.prototype.isGDVPrimeCEE = function() { return this.gdvPrimeCEE; }
+Config.prototype.isGDVSituation = function() { return this.gdvSituation; }
 
 Config.prototype.getCompteClients = function() { return this.compteClients; }
 Config.prototype.getJournalAchat = function() { return this.journalAchat; }
@@ -443,4 +448,3 @@ Config.prototype.isSpecHMDNP = function() { return this.specHMDNP; }
 Config.prototype.isSpecLCARMC = function() { return this.specLCARMC; }
 Config.prototype.isSpecLCAREC = function() { return this.specLCAREC; }
 Config.prototype.isSpecLCAOTC = function() { return this.specLCAOTC; }
-Config.prototype.isSpecREAFL = function() { return this.specREAFL; }
