@@ -81,7 +81,7 @@ try {
 function getVersion() {
   try {
 
-    return "9.9.0";
+    return "9.10.0";
 
   } catch (e) {
     recup_erreur(e);
@@ -114,48 +114,6 @@ function get_pref_module() {
   }
 }
 
-function get_pref_entreprise() {
-  try {
-
-    if (prefs.getPrefType("opensi.serveur.entreprise") == prefs.PREF_STRING){
-      return prefs.getCharPref("opensi.serveur.entreprise");
-    } else {
-      return "";
-    }
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
-function get_pref_login() {
-  try {
-
-    if (prefs.getPrefType("opensi.serveur.login") == prefs.PREF_STRING){
-      return prefs.getCharPref("opensi.serveur.login");
-    } else {
-      return "";
-    }
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
-function get_pref_password() {
-  try {
-
-    if (prefs.getPrefType("opensi.serveur.password") == prefs.PREF_STRING){
-      return prefs.getCharPref("opensi.serveur.password");
-    } else {
-      return "";
-    }
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
 function get_pref_login_check() {
   try {
 
@@ -184,13 +142,13 @@ function get_pref_password_check() {
   }
 }
 
-function get_pref_acces_check() {
+function get_pref_auth_cons_password() {
   try {
 
-    if (prefs.getPrefType("opensi.serveur.acces_check") == prefs.PREF_BOOL){
-      return prefs.getBoolPref("opensi.serveur.acces_check");
+    if (prefs.getPrefType("opensi.serveur.auth_cons_password") == prefs.PREF_BOOL){
+      return prefs.getBoolPref("opensi.serveur.auth_cons_password");
     } else {
-      return false;
+      return true;	// important redmine 15561 - initialisation
     }
 
   } catch (e) {
@@ -268,36 +226,6 @@ function set_pref_module(value) {
   }
 }
 
-function set_pref_entreprise(value) {
-  try {
-
-    prefs.setCharPref("opensi.serveur.entreprise", value);
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
-function set_pref_login(value) {
-  try {
-
-    prefs.setCharPref("opensi.serveur.login", value);
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
-function set_pref_password(value) {
-  try {
-
-    prefs.setCharPref("opensi.serveur.password", value);
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
 function set_pref_login_check(value) {
   try {
 
@@ -318,10 +246,10 @@ function set_pref_password_check(value) {
   }
 }
 
-function set_pref_acces_check(value) {
+function set_pref_auth_cons_password(value) {
   try {
 
-    prefs.setBoolPref("opensi.serveur.acces_check", value);
+    prefs.setBoolPref("opensi.serveur.auth_cons_password", value);
 
   } catch (e) {
     recup_erreur(e);
@@ -611,27 +539,6 @@ function debug(msg) {
 }
 
 
-/* renvoie une date au format yyyy:MM:dd */
-function prepareDateJava(val) {
-  try {
-
-    var retour = "";
-
-    if (val.length == 10) {
-      retour = val.substring(6,10) +':'+ val.substring(3,5) +':'+ val.substring(0,2);
-    }
-		else if (val.length == 8) {
-      retour = "20" + val.substring(6,8) +':'+ val.substring(3,5) +':'+ val.substring(0,2);
-    }
-
-    return retour;
-
-  } catch (e) {
-    recup_erreur(e);
-  }
-}
-
-
 /* renvoie une periode au format 20yy:MM:01 */
 function preparePeriodeJava(val) {
   try {
