@@ -51,11 +51,11 @@ function init() {
     document.getElementById('version').value = "v. "+ getVersion();
     if (get_pref_login_check()) {
       document.getElementById('login_check').checked = true;
-      if (get_pref_password_check()) {
+      if (get_pref_auth_cons_password() && get_pref_password_check()) {
         document.getElementById('password_check').checked = true;
       }
       else {
-        document.getElementById('password_check').removeAttribute("Checked");
+        document.getElementById('password_check').checked = false;
       }
     }
     else {
@@ -134,7 +134,7 @@ function checkLogin() {
 					oklog = false;
     		}
     		else if (isEmpty(servlet.value)) {
-      		alert("Vous devez pr\u00E9ciser le nom du servlet sur le serveur OpenSi");
+      		alert("Vous devez pr\u00E9ciser le nom de l'app sur le serveur OpenSi");
       		porttomcat.focus();
 					oklog = false;
     		}
@@ -291,7 +291,7 @@ function checkLogin2(httpRequest) {
 				else {
 					if (session.getAttribute('serveur')!=null && session.getAttribute('serveur')=="true") {
 						var serv = session.getElementsByTagName('server')[0];
-						 checkLoginChangementServeur(serv);
+						checkLoginChangementServeur(serv);
 					}
 					else {
 						var user = session.getElementsByTagName('user')[0];
@@ -300,6 +300,11 @@ function checkLogin2(httpRequest) {
 						if (versionServeur!=getVersion()) {
 							window.location = "update.html?versionServeur="+ versionServeur +"&urlupdate="+ user.getAttribute('urlupdate');
 						}
+						else if (user.getAttribute('Expired_Password')=="true") {
+							changePassword();
+							document.getElementById('label_connect_msg').value = "";
+							enableAll();
+						}
 						else {
 							checkLogin3(user);
 						}
@@ -325,39 +330,37 @@ function checkLogin3(user) {
       alert("Entreprise, login ou mot de passe incorrect");
       window.location = "chrome://opensi/content/login.xul";
       return -1;
-    } else {
-      var url="";
+    }
+		else {
+      var url = "";
       var root = user.getAttribute('root');
       var choix = document.getElementById('liste').value;
       set_pref_module(choix) ;
 
       if (root == "true") {
-        switch (choix) {
-          case 'Configuration' :
-            url = "chrome://opensi/content/config/main.xul";
-            break;
-          case 'Superviseur' :
-            url = "chrome://opensi/content/superviseur/main.xul";
-            break;
-          default:
-            alert("Entreprise, login ou mot de passe incorrect");
-            window.location = "chrome://opensi/content/login.xul";
-            return -1;
-            break;
-          }
+        if (choix=="Superviseur") {
+          url = "chrome://opensi/content/superviseur/main.xul";
+				}
+				else {
+					alert("Entreprise, login ou mot de passe incorrect");
+					window.location = "chrome://opensi/content/login.xul";
+					return -1;
+        }
 			}
 			else {
 				var entreprise = document.getElementById('Entreprise').value;
 			  var login = document.getElementById('login').value;
 		    var password = document.getElementById('password').value;
 				var administrateur = user.getAttribute('administrateur');
+				var authConsPassword = user.getAttribute("Auth_Cons_Password")=="true";
+				set_pref_auth_cons_password(authConsPassword);
 
 		    /* traite le cas de mmorisation d'identification */
 		    if (document.getElementById('login_check').checked) {
 		      var username = document.getElementById('Entreprise').value + '---' + document.getElementById('login').value;
 					var newloginInfo = new nsLoginInfo(hostname, formSubmitURL, httprealm, username, " ", 'login', 'password');
 		      set_pref_login_check(document.getElementById('login_check').checked);
-		      if (document.getElementById('password_check').checked) {
+		      if (authConsPassword && document.getElementById('password_check').checked) {
 		        set_pref_password_check(document.getElementById('password_check').checked);
 						var newloginInfo = new nsLoginInfo(hostname, formSubmitURL, httprealm, username, document.getElementById('password').value, 'login', 'password');
             if (username!=oldusername || document.getElementById('password').value!=oldpassword) {
@@ -392,10 +395,7 @@ function checkLogin3(user) {
 					}
 	       	catch (ex) {}
 
-		      set_pref_login("");
-			  	set_pref_entreprise("");
 		      set_pref_login_check(false);
-		      set_pref_password("");
 		      set_pref_password_check(false);
 		    }
 				var url;
@@ -493,7 +493,7 @@ function affichPassword() {
 function check_login() {
   try {
 
-    document.getElementById('password_check').disabled = !document.getElementById('login_check').checked;
+    document.getElementById('password_check').disabled = !document.getElementById('login_check').checked || !get_pref_auth_cons_password();
 
 	} catch (e) {
     recup_erreur(e);
@@ -567,3 +567,30 @@ function forgotPassword() {
     recup_erreur(e);
   }
 }
+
+
+function changePassword() {
+  try {
+
+		var entreprise = document.getElementById('Entreprise').value;
+		var login = document.getElementById('login').value;
+
+		var url = "chrome://opensi/content/popup-changePassword.xul?"+ nSession;
+    window.openDialog(url,'','chrome,modal,centerscreen', retourChangePassword, entreprise, login);
+
+	} catch (e) {
+    recup_erreur(e);
+  }
+}
+
+
+function retourChangePassword() {
+  try {
+
+		document.getElementById('password').value = "";
+		document.getElementById('password').focus();
+
+	} catch (e) {
+    recup_erreur(e);
+  }
+}
