@@ -357,7 +357,7 @@ function ofd_nouvelleInitialisation() {
 
 		document.getElementById("ofd-numSIRET").value = "";
 		document.getElementById("ofd-codeNAF").value = "";
-		document.getElementById("ofd-numTVAIntra").value = "";
+		document.getElementById("ofd-numeroTVA").value = "";
 		document.getElementById("ofd-villeRCS").value = "";
 
 		document.getElementById("ofd-dateCreation").value = "";
@@ -504,7 +504,7 @@ function ofd_enregisterInitialisation() {
 		var formeJuridique = document.getElementById("ofd-formeJuridique").value;
 		var numSIRET = document.getElementById("ofd-numSIRET").value;
 		var codeNAF = document.getElementById("ofd-codeNAF").value;
-		var numTVAIntra = document.getElementById("ofd-numTVAIntra").value;
+		var numeroTVA = document.getElementById("ofd-numeroTVA").value;
 		var villeRCS = document.getElementById("ofd-villeRCS").value;
 		var dateCreation = document.getElementById("ofd-dateCreation").value;
 		var dureeSociete = document.getElementById("ofd-dureeSociete").value;
@@ -561,7 +561,7 @@ function ofd_enregisterInitialisation() {
 			qSave.setParam("Forme_Juridique", formeJuridique);
 			qSave.setParam("Num_SIRET", numSIRET);
 			qSave.setParam("Code_NAF", codeNAF);
-			qSave.setParam("Numero_TVA", numTVAIntra);
+			qSave.setParam("Numero_TVA", numeroTVA);
 			qSave.setParam("Ville_RCS", villeRCS);
 			qSave.setParam("Date_Creation", dateCreation);
 			qSave.setParam("Duree_Societe", dureeSociete);
